@@ -10,7 +10,7 @@
 # 特記事項:
 # なし
 #
-# Copyright (c) 2012-2018, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+# Copyright (c) 2012-2019, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
 #
 #####################################################################
 package PGRex::command;
@@ -23,7 +23,7 @@ our @ISA = qw (Exporter);
 our @EXPORT = qw ($LS $CAT $CP $SU $RM $PS $GREP $ECHO $IFCONFIG $PING $READLINK
                   $MV $LN $UNAME $WHOAMI $WHICH $STTY $SERVICE $CRM $CRM_MON
                   $CRM_ATTRIBUTE $CRM_RESOURCE $SYNC $TAIL $PMSTART $PMSTOP
-                  $CRM_NODE $ROUTE $PIDOF $GZIP $BZIP2 $LSOF $KILL);
+                  $CRM_NODE $ROUTE $PIDOF $GZIP $BZIP2 $LSOF $KILL $TAR $AWK);
 
 our $LS            = "/bin/ls";
 our $CAT           = "/bin/cat";
@@ -58,5 +58,7 @@ our $GZIP          = "/bin/gzip";
 our $BZIP2         = "/usr/bin/bzip2";
 our $LSOF          = "/usr/sbin/lsof";
 our $KILL          = "/usr/bin/kill";
+our $TAR           = "/bin/tar";
+our $AWK           = "/usr/bin/awk";
 
 1;
