@@ -10,7 +10,7 @@
 # 特記事項:
 # なし
 #
-# Copyright (c) 2012-2018, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+# Copyright (c) 2012-2019, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
 #
 #####################################################################
 use warnings;
@@ -76,7 +76,7 @@ PG-REX を Slave として起動するツールです
 Slave として起動したいノードで実行します
 
 Usage:
-  pg-rex_slave_start [[-n] [-r] [-b | -f] | -c] [-d] [-s] [-o OPTIONS] [-h] [-v]
+  pg-rex_slave_start [[-n] [-r] [-b] | -c] [-d] [-s] [-h] [-v]
 
 Options:
   -n, --normal                    現在のDBクラスタを使用して Slave を起動します
@@ -85,20 +85,17 @@ Options:
                                   巻き戻し後、Slave を起動します
   -b, --basebackup                相手ノードをMasterとしてベースバックアップを
                                   取得後、Slave として起動します
-  -f, --force                     -b オプションに同じ。廃止予定
   -d, --dry-run                   データの変更とノードの起動の実行を伴わず、
                                   表示のみを行います
   -c, --check-only                DB クラスタの状態確認までを実施します
   -s, --shared-archive-directory  Master と Slave でアーカイブディレクトリを
                                   共有しているものとして動作します
-  -o, --options=OPTIONS           pg_basebackup に渡すオプションを指定します
   -h, --help                      Usage を表示して終了します
   -v, --version                   バージョン情報を表示して終了します
 
 _SLAVESTART_USAGE_
     
     SLAVESTART_MS0001   => "Ctrl+C は本プログラムでは無効です\n",
-    SLAVESTART_MS0002   => "相手のノードと同じクラスタ認証ファイルを配置する必要があります: [0]\n",
     SLAVESTART_MS0004   => "[0]. Pacemaker および Corosync が停止していることを確認\n",
     SLAVESTART_MS0005   => "...[NG]\n",
     SLAVESTART_MS0006   => "自身のノードで Pacemaker または Corosync が稼働しています\n".
@@ -172,8 +169,10 @@ _SLAVESTART_USAGE_
     SLAVESTART_MS0079   => "アーカイブログ \"[0]\" の拡張子が未知のため、完全性が確認できませんでした (未知の拡張子: [1])\n完全性の確認をスキップします\n",
     SLAVESTART_MS0080   => "WAL ファイルが存在するため、スクリプトを終了します\n",
     SLAVESTART_MS0081   => "Master のアーカイブディレクトリに Master の現在の LSN よりも進んだ WAL ファイルが存在します\n",
-    SLAVESTART_MS0082   => "--optionsまたはPG_BASEBACKUP_opt(pg-rex_tools.conf)の設定は無視します\n",
     SLAVESTART_MS0083   => "pg_wal の WAL ファイルの状態が不適切です。このまま Slave を起動するとアーカイブログが欠損するためスクリプトを終了します\n",
+    SLAVESTART_MS0084   => "-c オプションが指定されているため、非対話オプション(-n,-r,-b)を無視します\n",
+    SLAVESTART_MS0085   => "自身のノードの XLOG の位置のほうが相手のノードのタイムラインの分岐点よりも進んでいます ([0] > [1])\n",
+    SLAVESTART_MS0086   => "...[SKIP]\n",
     SLAVESTART_MS0087   => "タイムラインID [0] に対応するタイムライン履歴ファイルが相手のノードに存在しません: [1]\n",
     SLAVESTART_MS0099   => "内部エラー\n",
 
@@ -351,7 +350,6 @@ _SWITCHOVER_USAGE_
     COMMON_MS0014       => "pg_controldata の値の取得に失敗しました\n",
     COMMON_MS0015       => "相手のノード名の取得に失敗しました\n",
     COMMON_MS0016       => "相手ノードへの ssh 接続に失敗しました\n",
-    COMMON_MS0017       => "rsync コマンドの実行に失敗しました\n",
     COMMON_MS0018       => "scp コマンドの実行に失敗しました\n",
     COMMON_MS0019       => "corosync.conf に bindnetaddr の設定がありません\n",
     COMMON_MS0021       => "環境設定ファイル (pg-rex_tools.conf) の VIP_SLAVE の設定は enable または disable で指定してください\n",
@@ -372,10 +370,9 @@ _SWITCHOVER_USAGE_
     COMMON_MS0034       => "環境設定ファイル (pg-rex_tools.conf) の [0] の設定は、\n".
                            "manual、passfile、nopass のいずれかを指定してください\n",
     COMMON_MS0035       => "パスワードファイル \"[0]\" の権限が 600 ではありません\n",
-    COMMON_MS0036       => "指定された PGPATH ([0]) に PostgreSQL コマンドが存在しません\n".
-                           "環境設定ファイル (pg-rex_tools.conf) の PGPATH を環境にあわせて設定してください\n",
+    COMMON_MS0036       => "[0] に PostgreSQL コマンドが見つかりません。: [1]\n",
     COMMON_MS0037       => "PostgreSQL [0] には対応していません\n".
-                           "PostgreSQL 10 を使用してください\n",
+                           "PostgreSQL 11 を使用してください\n",
     COMMON_MS0038       => "Pacemaker [0] には対応していません\n".
                            "Pacemaker 1.1 を使用してください\n",
     COMMON_MS0039       => "[0] で bindnetaddr ([1]) に対応するネットワークインタフェースが見つかりませんでした\n",
@@ -392,6 +389,9 @@ _SWITCHOVER_USAGE_
     COMMON_MS0050       => "ロックファイル([0])の作成に失敗しました。\n",
     COMMON_MS0051       => "ロックファイル([0])の削除に失敗しました。: [1]\n",
     COMMON_MS0052       => "[0] はIPv4の形式ではありません。\n",
+    COMMON_MS0053       => "[0] が見つかりません: [1]\n",
+    COMMON_MS0054       => "アーカイブファイル \"[0]\" のサイズが0のため、スクリプトを終了します\n",
+    COMMON_MS0055       => "アーカイブログ \"[0]\" のサイズが制御ファイルの情報([1])と一致しないため、スクリプトを終了します\n",
 };
 
 1;
